==> ejc-prjfinance-api-3.0.1-20210731.074348-51-sources.jar: com/ejianc/business/prjfinance/vo/PrjQualitySafetyPenaltyVO.java <==
package com.ejianc.business.prjfinance.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 质安罚款
 * 
 * @author generator
 * 
 */
public class PrjQualitySafetyPenaltyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 主题
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private java.math.BigDecimal penaltyMny; // 罚款金额
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private java.util.Date dealDate; // 办理日期
    private Long dealPersonId; // 经办人id
    private String dealPerson; // 经办人
    private java.math.BigDecimal totalPenaltyMny; // 累计罚款金额
    private String memo; // 罚款事由

    /**
     * 所属组织Id
     */
    private Long orgId;

    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 主题
     */
    public String getName() {
        return name;
    }

    /**
     * 主题
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 罚款金额
     */
    public java.math.BigDecimal getPenaltyMny() {
        return penaltyMny;
    }

    /**
     * 罚款金额
     */
    public void setPenaltyMny(java.math.BigDecimal penaltyMny) {
        this.penaltyMny = penaltyMny;
    }
    /**
     * 办理日期
     */
    public java.util.Date getDealDate() {
        return dealDate;
    }

    /**
     * 办理日期
     */
    public void setDealDate(java.util.Date dealDate) {
        this.dealDate = dealDate;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public Long getDealPersonId() {
        return dealPersonId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setDealPersonId(Long dealPersonId) {
        this.dealPersonId = dealPersonId;
    }
    /**
     * 经办人
     */
    public String getDealPerson() {
        return dealPerson;
    }

    /**
     * 经办人
     */
    public void setDealPerson(String dealPerson) {
        this.dealPerson = dealPerson;
    }
    /**
     * 累计罚款金额
     */
    public java.math.BigDecimal getTotalPenaltyMny() {
        return totalPenaltyMny;
    }

    /**
     * 累计罚款金额
     */
    public void setTotalPenaltyMny(java.math.BigDecimal totalPenaltyMny) {
        this.totalPenaltyMny = totalPenaltyMny;
    }
    /**
     * 罚款事由
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 罚款事由
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
}

==> ejc-prjfinance-api-3.0.1-20210806.070011-81-sources.jar: com/ejianc/business/prjfinance/vo/PrjQualitySafetyPenaltyVO.java <==
package com.ejianc.business.prjfinance.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 质安罚款
 * 
 * @author generator
 * 
 */
public class PrjQualitySafetyPenaltyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 主题
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private java.math.BigDecimal penaltyMny; // 罚款金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date dealDate; // 办理日期
    private Long dealPersonId; // 经办人id
    private String dealPerson; // 经办人
    private java.math.BigDecimal totalPenaltyMny; // 累计罚款金额
    private String memo; // 罚款事由

    /**
     * 所属组织Id
     */
    private Long orgId;

    private String billStateName;


    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 主题
     */
    public String getName() {
        return name;
    }

    /**
     * 主题
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 罚款金额
     */
    public java.math.BigDecimal getPenaltyMny() {
        return penaltyMny;
    }

    /**
     * 罚款金额
     */
    public void setPenaltyMny(java.math.BigDecimal penaltyMny) {
        this.penaltyMny = penaltyMny;
    }
    /**
     * 办理日期
     */
    public java.util.Date getDealDate() {
        return dealDate;
    }

    /**
     * 办理日期
     */
    public void setDealDate(java.util.Date dealDate) {
        this.dealDate = dealDate;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public Long getDealPersonId() {
        return dealPersonId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setDealPersonId(Long dealPersonId) {
        this.dealPersonId = dealPersonId;
    }
    /**
     * 经办人
     */
    public String getDealPerson() {
        return dealPerson;
    }

    /**
     * 经办人
     */
    public void setDealPerson(String dealPerson) {
        this.dealPerson = dealPerson;
    }
    /**
     * 累计罚款金额
     */
    public java.math.BigDecimal getTotalPenaltyMny() {
        return totalPenaltyMny;
    }

    /**
     * 累计罚款金额
     */
    public void setTotalPenaltyMny(java.math.BigDecimal totalPenaltyMny) {
        this.totalPenaltyMny = totalPenaltyMny;
    }
    /**
     * 罚款事由
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 罚款事由
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
}
